PdfArray<T extends PdfDataType> class

Inheritance

Constructors

PdfArray([Iterable<T>? values])

Properties

hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
no setter
isNotEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<T>
final

Methods

add(T v) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfObjectBase<PdfDataType> o, PdfStream s, [int? indent]) → void
override
toList() → Uint8List
inherited
toString([int? indent]) → String
A string representation of this object.
inherited
uniq() → void
Make all values unique, preserving the order

Operators

operator ==(Object other) → bool
The equality operator.
override