PdfObjectBase<T extends PdfDataType> class

Mixed-in types
Implementers

Constructors

PdfObjectBase({required int objser, int objgen = 0, required T params, required PdfSettings settings})

Properties

elapsedStopwatch → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
objgen → int
This is the generation number for this object.
final
objser → int
This is the unique serial number for this object.
final
params → T
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PdfSettings
final
size ↔ int
getter/setter pairinherited

Methods

debugFill(String value) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfStream s) → int
ref() → PdfIndirect
Returns the unique serial number in Pdf format
setInsertion(PdfStream os, [int size = _maxSize]) → void
inherited
startStopwatch() → void
inherited
stopStopwatch() → void
inherited
toString() → String
A string representation of this object.
inherited
writeContent(PdfStream s) → void
writeDebug(PdfStream os) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited