PdfObject<T extends PdfDataType> class

Base Object used in the PDF file

Inheritance
Implementers

Constructors

PdfObject(PdfDocument pdfDocument, {required T params, int objgen = 0, int? objser})
Create a base Object used in the PDF file

Properties

elapsedStopwatch → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inUse ↔ bool
getter/setter pair
objgen → int
This is the generation number for this object.
finalinherited
objser → int
This is the unique serial number for this object.
finalinherited
params → T
finalinherited
pdfDocument → PdfDocument
This allows any Pdf object to refer to the document being constructed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PdfSettings
finalinherited
size ↔ int
getter/setter pairinherited

Methods

debugFill(String value) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfStream s) → int
inherited
prepare() → void
Prepare the object to be written to the stream
ref() → PdfIndirect
Returns the unique serial number in Pdf format
inherited
setInsertion(PdfStream os, [int size = _maxSize]) → void
inherited
startStopwatch() → void
inherited
stopStopwatch() → void
inherited
toString() → String
A string representation of this object.
override
writeContent(PdfStream s) → void
inherited
writeDebug(PdfStream os) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited