SvgGradient class abstract

Inheritance
Implementers

Constructors

SvgGradient(GradientUnits? gradientUnits, SvgTransform transform, List<PdfColor?> colors, List<double> stops, List<double> opacityList)
const

Properties

color → PdfColor?
finalinherited
colors → List<PdfColor?>
final
gradientUnits → GradientUnits?
final
hashCode → int
The hash code for this object.
no setterinherited
inherit → bool
finalinherited
isEmpty → bool
no setteroverride
isNotEmpty → bool
no setterinherited
opacity → double?
finalinherited
opacityList → List<double>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stops → List<double>
final
transform → SvgTransform
final

Methods

buildGradient(SvgOperation op, PdfGraphics canvas, List<PdfColor?> colors) → PdfPattern
merge(SvgColor other) → SvgColor
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFillColor(SvgOperation op, PdfGraphics canvas) → void
override
setStrokeColor(SvgOperation op, PdfGraphics canvas) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited