SvgLinearGradient class

Inheritance

Constructors

SvgLinearGradient(GradientUnits? gradientUnits, double? x1, double? y1, double? x2, double? y2, SvgTransform transform, List<PdfColor?> colors, List<double> stops, List<double> opacityList)
const
SvgLinearGradient.fromXml(XmlElement element, SvgPainter painter)
factory

Properties

color → PdfColor?
finalinherited
colors → List<PdfColor?>
finalinherited
gradientUnits → GradientUnits?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inherit → bool
finalinherited
isEmpty → bool
no setterinherited
isNotEmpty → bool
no setterinherited
opacity → double?
finalinherited
opacityList → List<double>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stops → List<double>
finalinherited
transform → SvgTransform
finalinherited
x1 → double?
final
x2 → double?
final
y1 → double?
final
y2 → double?
final

Methods

buildGradient(SvgOperation op, PdfGraphics canvas, List<PdfColor?> colors) → PdfPattern
override
merge(SvgColor other) → SvgColor
inherited
mergeWith(SvgLinearGradient other) → SvgLinearGradient
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFillColor(SvgOperation op, PdfGraphics canvas) → void
inherited
setStrokeColor(SvgOperation op, PdfGraphics canvas) → void
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited