SvgTransform class

Constructors

SvgTransform(Matrix4? matrix)
const
SvgTransform.fromString(String? transform)
factory
SvgTransform.fromXml(XmlElement element)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
matrix → Matrix4?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const SvgTransform