PdfPreviewData class

Inheritance

Constructors

PdfPreviewData({PdfPageFormat? initialPageFormat, required LayoutCallback buildDocument, required Map<String, PdfPageFormat> pageFormats, required ComputePageFormat onComputeActualPageFormat})

Properties

actualPageFormat → PdfPageFormat
The page format of the document
no setter
buildDocument → LayoutCallback
final
computedPageFormat → PdfPageFormat
Computed page format
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
horizontal ↔ bool
Is the print horizontal
getter/setter pair
localPageFormat → String
no setter
pageFormat ↔ PdfPageFormat
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited